@@ -7,7 +7,9 @@ def reset_max_id_for_series(schema: str, table: str, col: str, cursor):
     cursor.execute(f"SELECT setval('{table}_{col}_seq', (SELECT MAX({col}) FROM \"{schema}.{table}\"));")
 
 
-Min_DB_Id_Series: Final = 10000
+Min_DB_Id_Series: Final = 100000
+MIN_TEST_Id_Series: Final = 10000
+MAX_TEST_Id_Series: Final = 20000
 
 
 # @ref https://www.postgresql.org/docs/current/functions-sequence.html
